@@ -10,7 +10,7 @@ import types
 
 from . import validators
 
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 # constants for DeletionPolicy
 Delete = 'Delete'
@@ -27,7 +27,8 @@ class BaseAWSObject(object):
         # Cache the keys for validity checks
         self.propnames = self.props.keys()
         self.attributes = ['DependsOn', 'DeletionPolicy',
-                           'Metadata', 'UpdatePolicy']
+                           'Metadata', 'UpdatePolicy',
+                           'Condition']
 
         # unset/None is also legal
         if title and not valid_names.match(title):
@@ -58,59 +59,64 @@ class BaseAWSObject(object):
         if self.template is not None:
             self.template.add_resource(self)
 
-    def __getattr__(self, title):
+    def __getattr__(self, name):
         try:
-            return self.properties.__getitem__(title)
+            return self.properties.__getitem__(name)
         except KeyError:
-            raise AttributeError(title)
+            # Fall back to the name attribute in the object rather than
+            # in the properties dict. This is for non-OpenStack backwards
+            # compatibility since OpenStack objects use a "name" property.
+            if name == 'name':
+                return self.__getattribute__('title')
+            raise AttributeError(name)
 
-    def __setattr__(self, title, value):
-        if title in self.__dict__.keys() \
+    def __setattr__(self, name, value):
+        if name in self.__dict__.keys() \
                 or '_BaseAWSObject__initialized' not in self.__dict__:
-            return dict.__setattr__(self, title, value)
-        elif title in self.propnames:
+            return dict.__setattr__(self, name, value)
+        elif name in self.propnames:
             # Check the type of the object and compare against what we were
             # expecting.
-            expected_type = self.props[title][0]
+            expected_type = self.props[name][0]
 
             # If the value is a AWSHelperFn we can't do much validation
             # we'll have to leave that to Amazon.  Maybe there's another way
             # to deal with this that we'll come up with eventually
             if isinstance(value, AWSHelperFn):
-                return self.properties.__setitem__(title, value)
+                return self.properties.__setitem__(name, value)
 
             # If it's a function, call it...
             elif isinstance(expected_type, types.FunctionType):
                 value = expected_type(value)
-                return self.properties.__setitem__(title, value)
+                return self.properties.__setitem__(name, value)
 
             # If it's a list of types, check against those types...
             elif isinstance(expected_type, list):
                 # If we're expecting a list, then make sure it is a list
                 if not isinstance(value, list):
-                    self._raise_type(title, value, expected_type)
+                    self._raise_type(name, value, expected_type)
 
                 # Iterate over the list and make sure it matches our
                 # type checks
                 for v in value:
                     if not isinstance(v, tuple(expected_type)):
-                        self._raise_type(title, v, expected_type)
+                        self._raise_type(name, v, expected_type)
                 # Validated so assign it
-                return self.properties.__setitem__(title, value)
+                return self.properties.__setitem__(name, value)
 
             # Single type so check the type of the object and compare against
             # what we were expecting. Special case AWS helper functions.
             elif isinstance(value, expected_type):
-                return self.properties.__setitem__(title, value)
+                return self.properties.__setitem__(name, value)
             else:
-                self._raise_type(title, value, expected_type)
+                self._raise_type(name, value, expected_type)
 
         raise AttributeError("%s object does not support attribute %s" %
-                            (self.type, title))
+                             (self.type, name))
 
-    def _raise_type(self, title, value, expected_type):
+    def _raise_type(self, name, value, expected_type):
         raise TypeError('%s is %s, expected %s' %
-                        (title, type(value), expected_type))
+                        (name, type(value), expected_type))
 
     def validate(self):
         pass
@@ -164,8 +170,8 @@ def validate_pausetime(pausetime):
 
 class UpdatePolicy(BaseAWSObject):
     props = {
-        'MaxBatchSize': (basestring, False),
-        'MinInstancesInService': (basestring, False),
+        'MaxBatchSize': (validators.positive_integer, False),
+        'MinInstancesInService': (validators.integer, False),
         'PauseTime': (validate_pausetime, False),
     }
 
@@ -229,6 +235,38 @@ class If(AWSHelperFn):
         return self.data
 
 
+class Equals(AWSHelperFn):
+    def __init__(self, value_one, value_two):
+        self.data = {'Fn::Equals': [value_one, value_two]}
+
+    def JSONrepr(self):
+        return self.data
+
+
+class And(AWSHelperFn):
+    def __init__(self, cond_one, cond_two, *conds):
+        self.data = {'Fn::And': [cond_one, cond_two] + list(conds)}
+
+    def JSONrepr(self):
+        return self.data
+
+
+class Or(AWSHelperFn):
+    def __init__(self, cond_one, cond_two, *conds):
+        self.data = {'Fn::Or': [cond_two, cond_two] + list(conds)}
+
+    def JSONrepr(self):
+        return self.data
+
+
+class Not(AWSHelperFn):
+    def __init__(self, cond):
+        self.data = {'Fn::Not': [self.getdata(cond)]}
+
+    def JSONrepr(self):
+        return self.data
+
+
 class Join(AWSHelperFn):
     def __init__(self, delimiter, values):
         self.data = {'Fn::Join': [delimiter, values]}
@@ -261,6 +299,14 @@ class Ref(AWSHelperFn):
         return self.data
 
 
+class Condition(AWSHelperFn):
+    def __init__(self, data):
+        self.data = {'Condition': self.getdata(data)}
+
+    def JSONrepr(self):
+        return self.data
+
+
 class awsencode(json.JSONEncoder):
     def default(self, obj):
         if hasattr(obj, 'JSONrepr'):
@@ -303,8 +349,8 @@ class Template(object):
     def add_description(self, description):
         self.description = description
 
-    def add_condition(self, title, condition):
-        self.conditions[title] = condition
+    def add_condition(self, name, condition):
+        self.conditions[name] = condition
 
     def handle_duplicate_key(self, key):
         raise ValueError('duplicate key "%s" detected' % key)
@@ -324,8 +370,8 @@ class Template(object):
     def add_output(self, output):
         return self._update(self.outputs, output)
 
-    def add_mapping(self, title, mapping):
-        self.mappings[title] = mapping
+    def add_mapping(self, name, mapping):
+        self.mappings[name] = mapping
 
     def add_parameter(self, parameter):
         return self._update(self.parameters, parameter)
