@@ -3,30 +3,8 @@
 #
 # See LICENSE file for full license.
 
-from . import AWSObject, AWSProperty
-from .validators import integer
-
-
-class Alarm(AWSObject):
-    type = "AWS::CloudWatch::Alarm"
-
-    props = {
-        'ActionsEnabled': (basestring, False),
-        'AlarmActions': (list, False),
-        'AlarmDescription': (basestring, False),
-        'AlarmName': (basestring, False),
-        'ComparisonOperator': (basestring, True),
-        'Dimensions': (list, False),
-        'EvaluationPeriods': (integer, True),
-        'InsufficientDataActions': (list, False),
-        'MetricName': (basestring, True),
-        'Namespace': (basestring, True),
-        'OKActions': (list, False),
-        'Period': (integer, True),
-        'Statistic': (basestring, True),
-        'Threshold': (integer, True),
-        'Unit': (basestring, False),
-    }
+from . import AWSObject, AWSProperty, Ref
+from .validators import integer, positive_integer, boolean
 
 
 class MetricDimension(AWSProperty):
@@ -34,3 +12,25 @@ class MetricDimension(AWSProperty):
         'Name': (basestring, True),
         'Value': (basestring, True),
     }
+
+
+class Alarm(AWSObject):
+    type = "AWS::CloudWatch::Alarm"
+
+    props = {
+        'ActionsEnabled': (boolean, False),
+        'AlarmActions': ([basestring, Ref], False),
+        'AlarmDescription': (basestring, False),
+        'AlarmName': (basestring, False),
+        'ComparisonOperator': (basestring, True),
+        'Dimensions': ([MetricDimension], False),
+        'EvaluationPeriods': (positive_integer, True),
+        'InsufficientDataActions': ([basestring, Ref], False),
+        'MetricName': (basestring, True),
+        'Namespace': (basestring, True),
+        'OKActions': ([basestring, Ref], False),
+        'Period': (positive_integer, True),
+        'Statistic': (basestring, True),
+        'Threshold': (integer, True),
+        'Unit': (basestring, False),
+    }
